(window.webpackJsonp=window.webpackJsonp||[]).push([[1],{132:function(t,e,n){"use strict";e.a=function(t){var e=t.$axios,n=window.location.host;e.setBaseURL("http://".concat(n,"/api"))}},133:function(t,e,n){"use strict";n(53);var r=n(10),o=n(6),c=function t(e){Object(o.a)(this,t),this.usersEnabled=e.users_enabled};e.a=function(){var t=Object(r.a)(regeneratorRuntime.mark((function t(e,n){var r,o,f;return regeneratorRuntime.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:return r=e.app,t.next=3,r.$axios.get("/system");case 3:o=t.sent,f=new c(o.data),n("backend_settings",f);case 6:case"end":return t.stop()}}),t)})));return function(e,n){return t.apply(this,arguments)}}()},178:function(t,e,n){var content=n(235);"string"==typeof content&&(content=[[t.i,content,""]]),content.locals&&(t.exports=content.locals);(0,n(83).default)("6570a8f6",content,!0,{sourceMap:!1})},197:function(t,e,n){"use strict";var r={},o=n(56),c=n(104),f=n.n(c),l=n(274),component=Object(o.a)(r,(function(){var t=this.$createElement,e=this._self._c||t;return e("v-app",[e("nuxt")],1)}),[],!1,null,null,null);e.a=component.exports;f()(component,{VApp:l.a})},208:function(t,e,n){n(209),t.exports=n(210)},234:function(t,e,n){"use strict";n(178)},235:function(t,e,n){(e=n(82)(!1)).push([t.i,"h1[data-v-495dc2cf]{font-size:20px}",""]),t.exports=e},41:function(t,e,n){"use strict";var r={layout:"empty",props:{error:{type:Object,default:null}},data:function(){return{pageNotFound:"404 Not Found",otherError:"An error occurred"}},head:function(){return{title:404===this.error.statusCode?this.pageNotFound:this.otherError}}},o=(n(234),n(56)),c=n(104),f=n.n(c),l=n(274),component=Object(o.a)(r,(function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("v-app",{attrs:{dark:""}},[404===t.error.statusCode?n("h1",[t._v("\n    "+t._s(t.pageNotFound)+"\n  ")]):n("h1",[t._v("\n    "+t._s(t.otherError)+"\n  ")]),t._v(" "),n("NuxtLink",{attrs:{to:"/"}},[t._v(" Home page ")])],1)}),[],!1,null,"495dc2cf",null);e.a=component.exports;f()(component,{VApp:l.a})}},[[208,6,2,7]]]);