(window.webpackJsonp=window.webpackJsonp||[]).push([[5],{383:function(e,t,n){"use strict";n.r(t);var r={name:"Packages",computed:{query:function(){return this.$route.query.q||null}}},c=n(56),component=Object(c.a)(r,(function(){var e=this.$createElement;return(this._self._c||e)("div",[this._v("Found packages by query: "+this._s(this.query))])}),[],!1,null,null,null);t.default=component.exports}}]);