(window.webpackJsonp=window.webpackJsonp||[]).push([[3],{306:function(e,t,n){var content=n(344);"string"==typeof content&&(content=[[e.i,content,""]]),content.locals&&(e.exports=content.locals);(0,n(83).default)("78ccd4bc",content,!0,{sourceMap:!1})},307:function(e,t,n){var content=n(346);"string"==typeof content&&(content=[[e.i,content,""]]),content.locals&&(e.exports=content.locals);(0,n(83).default)("6610d69e",content,!0,{sourceMap:!1})},343:function(e,t,n){"use strict";n(306)},344:function(e,t,n){(t=n(82)(!1)).push([e.i,".search_page[data-v-26032f51]{background-color:#00f}",""]),e.exports=t},345:function(e,t,n){"use strict";n(307)},346:function(e,t,n){(t=n(82)(!1)).push([e.i,".w-100{width:100%}.mw-40{max-width:40%}.mw-60{max-width:60%}.centered{position:absolute;top:50%;left:50%;margin-right:-50%;transform:translate(-50%,-50%)}.v-list{padding-top:0!important;padding-bottom:0!important}",""]),e.exports=t},384:function(e,t,n){"use strict";n.r(t);n(26),n(146),n(53);var r=n(10),c={data:function(){return{isLoading:!1,items:[],searchTerm:null}},watch:{searchTerm:function(e){var t=this;return Object(r.a)(regeneratorRuntime.mark((function n(){var r;return regeneratorRuntime.wrap((function(n){for(;;)switch(n.prev=n.next){case 0:if(!(null===e||e.length<2)){n.next=3;break}return t.items=[],n.abrupt("return");case 3:return n.next=5,t.$axios.get("/packages",{params:{page:0,name:e,limit:10},progress:!1});case 5:r=n.sent,t.items=r.data;case 7:case"end":return n.stop()}}),n)})))()}},mounted:function(){var e=this;return Object(r.a)(regeneratorRuntime.mark((function t(){return regeneratorRuntime.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:if(!e.$backend_settings.usersEnabled||e.$auth.loggedIn){t.next=3;break}return t.next=3,e.$router.push("/login");case 3:case"end":return t.stop()}}),t)})))()},methods:{logout:function(){var e=this;return Object(r.a)(regeneratorRuntime.mark((function t(){return regeneratorRuntime.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:return t.next=2,e.$auth.logout();case 2:return t.next=4,e.$router.push("/login");case 4:case"end":return t.stop()}}),t)})))()},search:function(e){this.$router.push("/packages?q=".concat(e))},raw_search:function(){this.search(this.searchTerm)}}},o=(n(343),n(345),n(56)),l=n(104),m=n.n(l),h=n(381),f=n(313),d=n(282),component=Object(o.a)(c,(function(){var e=this,t=e.$createElement,n=e._self._c||t;return n("div",{staticClass:"w-100 search_page"},[n("v-autocomplete",{staticClass:"centered w-100 mw-60",attrs:{flat:"",rounded:"",autofocus:!0,clearable:!0,"hide-no-data":!0,items:e.items,"search-input":e.searchTerm,label:"Search packages","append-icon":null,placeholder:"Start typing to Search","prepend-icon":"mdi-magnify","search-input.sync":"","item-text":"name","item-value":"name"},on:{"update:searchInput":function(t){e.searchTerm=t},"update:search-input":function(t){e.searchTerm=t},keyup:function(t){return t.type.indexOf("key")||13===t.keyCode?e.raw_search(t):null},change:e.search},scopedSlots:e._u([{key:"item",fn:function(data){return[[n("v-list-item-avatar",[n("img",{attrs:{src:"languages/"+data.item.language.toLowerCase()+".svg"}})]),e._v(" "),n("v-list-item-content",[n("v-list-item-title",[e._v(e._s(data.item.name))])],1)]]}}])})],1)}),[],!1,null,"26032f51",null);t.default=component.exports;m()(component,{VAutocomplete:h.a,VListItemAvatar:f.a,VListItemContent:d.a,VListItemTitle:d.b})}}]);